<?php
##############################################################
# FILENAME  : acp_rivals_report_match.php
# COPYRIGHT : (c) 2008, Tyler N. King <aibotca@yahoo.ca>
# http://opensource.org/licenses/gpl-license.php GNU Public License
##############################################################
if ( !defined ( 'IN_PHPBB' ) )
{
	exit;
}

/**
 * Report a Match
 * Called from acp_rivals with mode == 'report_match'
 */
function acp_rivals_report_match ( $id, $mode, $u_action )
{
	global	$db, $user, $template;
	global	$phpbb_root_path, $phpbb_admin_path, $phpEx;

	$clan	= new clan ( );
	$ladder	= new ladder ( );

	$submit		= request_var ( 'submit', '' );
	$ladder_id	= request_var ( 'ladder_id', 0 );

	// Are we submitting a form?
	if ( !empty ( $submit ) )
	{
		// Yes, handle the form
		$clan_winner	= request_var ( 'clan_winner', 0 );
		$clan_looser	= request_var ( 'clan_looser', 0 );

		// Insert the match into the database.
		$sql_array	= array (
			'match_challenger' => $clan_winner,
			'match_challengee' => $clan_looser,
			'match_finishtime' => time ( ),
			'match_ladder' => $ladder_id,
			'match_details' => ''
		);
		$sql		= "INSERT INTO " . MATCHES_TABLE . " " . $db->sql_build_array ( 'INSERT', $sql_array );
		$db->sql_query ( $sql );

		// ELO scoring system.
		$score_winner	= calculate_elo ( $clan->data ( 'clan_score', $clan_winner, $ladder_id ), $clan->data ( 'clan_score', $clan_looser, $ladder_id ), true );
		$score_looser	= calculate_elo ( $clan->data ( 'clan_score', $clan_looser, $ladder_id ), $clan->data ( 'clan_score', $clan_winner, $ladder_id ), false );

		// Calculate the new streaks.
		$streak_winner	= ( $clan->data ( 'clan_streak', $clan_winner, $ladder_id ) < 0 ) ? 'clan_streak = 0' : 'clan_streak = clan_streak + 1';
		$streak_looser	= ( $clan->data ( 'clan_streak', $clan_winner, $ladder_id ) < 0 ) ? 'clan_streak = clan_streak - 1' : 'clan_streak = 0';

		$sql	= "UPDATE " . CLANDATA_TABLE . " SET clan_wins = clan_wins + 1, clan_lastscore = clan_score, clan_score = $score_winner, $streak_winner WHERE clan_id = $clan_winner AND clan_ladder = " . $ladder_id;
		$db->sql_query ( $sql );

		$sql	= "UPDATE " . CLANDATA_TABLE . " SET clan_losses = clan_losses + 1, clan_lastscore = clan_score, clan_score = $score_looser, $streak_looser WHERE clan_id = $clan_looser AND clan_ladder = " . $ladder_id;
		$db->sql_query ( $sql );

		// Completed. Let the user know.
		trigger_error ( 'MATCH_REPORTED' );
	}
	else
	{
		// Load the clan data?
		if ( !empty ( $ladder_id ) )
		{
			// Yes. A ladder was selected.
			// Get the clans for the ladder_id.
			$sql	= "SELECT cd.*, c.* FROM " . CLANDATA_TABLE . " cd, " . CLANS_TABLE . " c WHERE cd.clan_ladder = $ladder_id AND cd.clan_id = c.clan_id ORDER BY c.clan_name ASC";
			$result	= $db->sql_query ( $sql );

			while ( $row = $db->sql_fetchrow ( $result ) )
			{
				// Assign the clans to the template.
				$template->assign_block_vars ( 'block_clans', array (
					'CLAN_NAME' => $clan->data ( 'clan_name', $row[ 'clan_id' ] ),
					'CLAN_ID' => $row[ 'clan_id' ] )
				);
			}

			$db->sql_freeresult ( $result );

			$template->assign_vars ( array ( 'LADDER_ID' => $ladder_id ) );
		}
		else
		{
			// No. No ladder was selected.
			$has_ladderid	= false;

			// Loop through the ladders.
			$sql	= "SELECT l.*, p.* FROM " . LADDERS_TABLE . " l, " . PLATFORMS_TABLE . " p WHERE l.ladder_platform = p.platform_id";
			$result	= $db->sql_query ( $sql );

			while ( $row = $db->sql_fetchrow ( $result ) )
			{
				// Assign it to the template.
				$template->assign_block_vars ( 'block_ladders', array (
					'LADDER_NAME' => $row[ 'ladder_name' ],
					'PLATFORM' => $row[ 'platform_name' ] )
				);

				$sql_2		= "SELECT * FROM " . LADDERS_TABLE . " WHERE ladder_parent = " . $row[ 'ladder_id' ];
				$result_2	= $db->sql_query ( $sql_2 );

				// Loop through the ladder's sub-ladders.
				while ( $row_2 = $db->sql_fetchrow ( $result_2 ) )
				{
					// Assign them to the template.
					$template->assign_block_vars ( 'block_ladders.block_subladders', array (
						'LADDER_ID' => $row_2[ 'ladder_id' ],
						'LADDER_NAME' => $row_2[ 'ladder_name' ] )
					);
				}

				$db->sql_freeresult ( $result_2 );
			}

			$db->sql_freeresult ( $result );
		}

		// Assign the other variables to the template.
		$template->assign_vars ( array (
			'U_ACTION' => $u_action,
			'HAS_LADDERID' => $has_ladderid )
		);
	}
}

?>
