<?php
##############################################################
# FILENAME  : ucp_rivals_add_challenge.php
# COPYRIGHT : (c) 2008, Tyler N. King <aibotca@yahoo.ca>
# http://opensource.org/licenses/gpl-license.php GNU Public License
##############################################################
if ( !defined ( 'IN_PHPBB' ) )
{
	exit;
}

/**
 * Add a Challenge
 * Called from ucp_rivals with mode == 'add_challenge'
 */
function ucp_rivals_add_challenge ( $id, $mode, $u_action )
{
	global	$db, $user, $template, $config;
	global	$phpbb_root_path, $phpEx;

	$clan	= new clan ( );
	$ladder	= new ladder ( );

	// Are we submitting a form?
	$submit	= request_var ( 'submit', '' );
	if ( !empty ( $submit ) )
	{
		$challengee			= $db->sql_escape ( utf8_normalize_nfc ( request_var ( 'challengee', '' ) ) );
		$challenge_details	= $db->sql_escape ( utf8_normalize_nfc ( request_var ( 'challenge_details', '', true ) ) );
		$ladder_id			= request_var ( 'ladder_id', 0 );

		// Get the challengee's clan data.
		$sql	= "SELECT * FROM " . CLANS_TABLE . " WHERE (clan_name = '$challengee' OR clan_id = " . intval ( $challengee ) . ")";
		$result	= $db->sql_query ( $sql );
		$row	= $db->sql_fetchrow ( $result );
		$db->sql_freeresult ( $result );

		if ( sizeof ( $row ) == 0 )
		{
			// Challengee is not in the database.
			trigger_error ( 'NONEXISTANT_CLAN' );
		}
		else
		{
			// Chellengee is in the database. Get their record.
			$challengee	= $row[ 'clan_id' ];
		} 

		// Compare the ladder chosen.
		$sql	= "SELECT * FROM " . CLANDATA_TABLE . " WHERE clan_ladder = $ladder_id AND clan_id = " . $challengee;
		$result	= $db->sql_query ( $sql );
		$row	= $db->sql_fetchrow ( $result );
		$db->sql_freeresult ( $result );

		if ( sizeof ( $row ) == 0 )
		{
			// Challengee is not in the same ladder as the logged-in clan.
			trigger_error ( 'NONEXISTANT_CLAN2' );
		}

		// If Swap is on, then check for 3 ranks above or below.
		if ( $ladder->data ( 'ladder_ranking', $clan_ladder ) == 1 )
		{
			// Swap is on, check ranking.
			$challenger_rank	= $clan->data ( 'clan_current_rank', $clan->data[ 'clan_id' ], $ladder_id );
			$rank				= $clan->data ( 'clan_current_rank', $challengee, $ladder_id );

			if ( ( ( $rank - $challenger_rank ) >= -3 && ( $rank - $challenger_rank ) <= 0 ) || ( $challenger_rank - $rank ) <= 3 )
			{
				// Everything is OK.
			}
			else
			{
				// They are out of the ranking range. Let the user know.
				trigger_error ( 'RANKING_RANGE' );
			}
		}

		// Get all the clans owned by the user.
		$sql	= "SELECT clan_id FROM " . CLANS_TABLE . " WHERE clan_owner = {$user->data[ 'user_id' ]} OR clan_ownerb = " . $user->data[ 'user_id' ];
		$result	= $db->sql_query ( $sql );

		while ( $row = $db->sql_fetchrow ( $result ) )
		{
			if ( $challengee == $row[ 'clan_id' ] )
			{
				// They are trying to challenge themself. Warn them.
				trigger_error ( 'CHEATER' );
			}
		}

		$db->sql_freeresult ( $result );

		// Finally. Insert the challenge.
		$sql_array	= array (
			'challenger' => $clan->data[ 'clan_id' ],
			'challengee' => $challengee,
			'challenge_details' => $challenge_details,
			'challenge_posttime' => time ( ),
			'challenge_ladder' => $ladder_id
		);
		$sql		= "INSERT INTO " . CHALLENGES_TABLE . " " . $db->sql_build_array ( 'INSERT', $sql_array );
		$db->sql_query ( $sql );

		// Get all the ladder's root details for the PM.
		$ladder_data	= $ladder->get_roots ( $ladder_id );

		// Send a PM to the challengee.
		$subject	= sprintf ( $user->lang[ 'PM_CHALLENGE' ], $clan->data[ 'clan_name' ] );
		$message	= sprintf ( $user->lang[ 'PM_CHALLENGETXT' ], $config[ 'server_protocol' ], $config[ 'server_name' ], $config[ 'script_path' ], $clan->data[ 'clan_id' ], $clan->data[ 'clan_name' ], $ladder_data[ 'PLATFORM_NAME' ], $ladder_data[ 'LADDER_NAME' ], $ladder_data[ 'SUBLADDER_NAME' ] );
		insert_pm ( $clan->data ( 'clan_owner', $challengee ), $user->data, $subject, $message );

		// Completed. Let the user know.
		trigger_error ( 'CHALLENGE_ADDED' );
	}
	else
	{
		// Check if the clan is apart of a ladder yet.
		if ( sizeof ( $clan->data[ 'clan_ladders' ] ) == 0 )
		{
			// They are not apart of a ladder. Deny them.
			trigger_error ( 'CLAN_NOTIN_LADDER' );
		}

		$clan_id	= request_var ( 'clan_id', 0 );

		foreach ( $clan->data[ 'clan_ladders' ] AS $value )
		{
			// Get the ladder's roots to show.
			$ladder_data	= $ladder->get_roots ( $value );

			// Check to see if the ladder is locked.
			if ( $ladder_data[ 'SUBLADDER_LOCKED' ] == 0 )
			{
				// Assign each ladder to the template.
				$template->assign_block_vars ( 'block_ladders', array (
					'LADDER_ID' => $value,
					'PLATFORM' => $ladder_data[ 'PLATFORM_NAME' ],
					'LADDER' => $ladder_data[ 'LADDER_NAME' ],
					'SUBLADDER' => $ladder_data[ 'SUBLADDER_NAME' ] )
				);
			}
		}

		// Assign the other variables to the template.
		$template->assign_vars ( array (
			'U_ACTION' => $u_action,
			'U_FIND_CLAN' => append_sid ( "{$phpbb_root_path}ucp.$phpEx", 'i=rivals&amp;mode=find_clan' ),
			'CLAN_ID' => ( $clan_id != 0 ) ? $clan_id : '' )
		);
	}
}

?>
