<?php
##############################################################
# FILENAME  : ucp_rivals_match_finder.php
# COPYRIGHT : (c) 2008, Tyler N. King <aibotca@yahoo.ca>
# http://opensource.org/licenses/gpl-license.php GNU Public License
##############################################################
if ( !defined ( 'IN_PHPBB' ) )
{
	exit;
}

define ( 'SEARCH_MATCH', 1 );
define ( 'ADD_MATCH', 2 );

/**
 * Match Finder
 * Called from ucp_rivals with mode == 'match_finder'
 */
function ucp_rivals_match_finder ( $id, $mode, $u_action )
{
	global	$db, $user, $template;
	global	$phpbb_root_path, $phpEx;

	$clan	= new clan ( );
	$ladder	= new ladder ( );

	// Are we submitting a form?
	$match_type	= request_var ( 'match_type', 0 );
	if ( $match_type == ADD_MATCH )
	{
		$match_time		= request_var ( 'match_time', 0 );
		$clan_ladder	= request_var ( 'clan_ladder', 0 );

		// Insert the clan into the match finder.
		$sql_array	= array (
			'match_clanid' => $clan->data[ 'clan_id' ],
			'match_ladder' => $clan_ladder,
			'match_time' => $match_time,
			'match_initaltime' => time ( )
		);
		$sql		= "INSERT INTO " . MATCHFINDER_TABLE . " " . $db->sql_build_array ( 'INSERT', $sql_array );
		$db->sql_query ( $sql );

		// Completed. Let the user know.
		trigger_error ( 'MATCH_FINDER_ADDED' );
	}
	else
	{
		// Check if the clan is apart of a ladder yet.
		if ( sizeof ( $clan->data[ 'clan_ladders' ] ) == 0 )
		{
			// They are not apart of a ladder. Deny them.
			trigger_error ( 'CLAN_NOTIN_LADDER' );
		}

		if ( $match_type == SEARCH_MATCH )
		{
			$match_time	= request_var ( 'match_time', 0 );

			// Get the clans open for a challenge during this time.
			$sql	= "SELECT * FROM " . MATCHFINDER_TABLE . " WHERE match_time <= $match_time AND match_ladder IN(" . implode ( ',', $clan->data[ 'clan_ladders' ] ) . ") AND match_clanid <> {$clan->data[ 'clan_id' ]} ORDER BY match_time DESC";
			$result	= $db->sql_query ( $sql );

			$i	= 0;
			while ( $row = $db->sql_fetchrow ( $result ) )
			{
				$match_expiretime	= date ( 'i', ( $row[ 'match_initaltime' ] + ( 60 * $row[ 'match_time' ] ) ) );
				if ( date ( 'i', time ( ) ) >= $match_expiretime )
				{
					// Clan is past it's set match time. Remove the expired match finder entry.
					$sql	= "DELETE FROM " . MATCHFINDER_TABLE . " WHERE match_id = " . $row[ 'match_id' ];
					$db->sql_query ( $sql );
				}
				else
				{
					// Assign each clan to the template.
					$clan_data	= $clan->data ( '*', $row[ 'match_clanid' ] );
					$template->assign_block_vars ( 'block_matchtime.block_clans', array (
						'U_CLAN' => append_sid ( "{$phpbb_root_path}rivals.$phpEx", 'clan_profile&amp;clan_id=' . $row[ 'match_clanid' ] ),
						'U_CHALLENGE' => append_sid ( "{$phpbb_root_path}ucp.$phpEx", 'i=rivals&amp;mode=add_challenge&amp;clan_id=' . $row[ 'match_clanid' ] ),
						'BG_COLOR' => ( $i % 2 ) ? 'bg1' : 'bg2',
						'ROW_COLOR' => ( $i % 2 ) ? 'row1' : 'row2',
						'CLAN_NAME' => $clan_data[ 'clan_name' ],
						'CLAN_WINS' => $clan_data[ 'clan_wins' ],
						'CLAN_LOSSES' => $clan_data[ 'clan_losses' ],
						'CLAN_STREAK' => $clan_data[ 'clan_streak' ] )
					);

					$i++;
				}
			}

			$db->sql_freeresult ( $result );
	
			if ( $i == 0 )
			{
				// No clans found. Let the user know.
				trigger_error ( 'NO_CLANS_FOUND' );
			}
		}
		else
		{
			// Build the minutes box.
			for ( $i = 5; $i <= 60; $i += 5 )
			{
				// Assign each minute time to the template.
				$template->assign_block_vars ( 'block_minutes', array ( 'MINUTE' => $i ) );
			}

			// Build the ladder list.
			foreach ( $clan->data[ 'clan_ladders' ] AS $value )
			{
				// Get the ladder's root detials to show.
				$ladder_data	= $ladder->get_roots ( $value );

				// Check to see if the ladder is locked.
				if ( $ladder_data[ 'SUBLADDER_LOCKED' ] == 0 )
				{
					// Assign each ladder to the template.
					$template->assign_block_vars ( 'block_ladders', array (
						'SUBLADDER_ID' => $value,
						'PLATFORM' => $ladder_data[ 'PLATFORM_NAME' ],
						'LADDER' => $ladder_data[ 'LADDER_NAME' ],
						'SUBLADDER' => $ladder_data[ 'SUBLADDER_NAME' ] )
					);
				}
			}
		}

		// Assign the other variables to the template.
		$template->assign_vars ( array ( 'U_ACTION' => $u_action ) );
	}
}

?>
