#
# $Id: $
#


# Table: 'phpbb_rivals_challenges'
CREATE TABLE phpbb_rivals_challenges (
	challenge_id INTEGER NOT NULL,
	challenge_ladder INTEGER DEFAULT 0 NOT NULL,
	challenger INTEGER DEFAULT 0 NOT NULL,
	challengee INTEGER DEFAULT 0 NOT NULL,
	challenge_posttime INTEGER DEFAULT 0 NOT NULL,
	challenge_details BLOB SUB_TYPE TEXT CHARACTER SET UTF8 DEFAULT '' NOT NULL
);;

ALTER TABLE phpbb_rivals_challenges ADD PRIMARY KEY (challenge_id);;


CREATE GENERATOR phpbb_rivals_challenges_gen;;
SET GENERATOR phpbb_rivals_challenges_gen TO 0;;

CREATE TRIGGER t_phpbb_rivals_challenges FOR phpbb_rivals_challenges
BEFORE INSERT
AS
BEGIN
	NEW.challenge_id = GEN_ID(phpbb_rivals_challenges_gen, 1);
END;;


# Table: 'phpbb_rivals_clanmembers'
CREATE TABLE phpbb_rivals_clanmembers (
	member_id INTEGER NOT NULL,
	member_clan INTEGER DEFAULT 0 NOT NULL,
	member_userid INTEGER DEFAULT 0 NOT NULL,
	member_status INTEGER DEFAULT 0 NOT NULL
);;

ALTER TABLE phpbb_rivals_clanmembers ADD PRIMARY KEY (member_id);;


CREATE GENERATOR phpbb_rivals_clanmembers_gen;;
SET GENERATOR phpbb_rivals_clanmembers_gen TO 0;;

CREATE TRIGGER t_phpbb_rivals_clanmembers FOR phpbb_rivals_clanmembers
BEFORE INSERT
AS
BEGIN
	NEW.member_id = GEN_ID(phpbb_rivals_clanmembers_gen, 1);
END;;


# Table: 'phpbb_rivals_clans'
CREATE TABLE phpbb_rivals_clans (
	clan_id INTEGER NOT NULL,
	clan_name VARCHAR(255) CHARACTER SET NONE DEFAULT '' NOT NULL,
	clan_tag VARCHAR(255) CHARACTER SET NONE DEFAULT '' NOT NULL,
	clan_tournaments BLOB SUB_TYPE TEXT CHARACTER SET UTF8 DEFAULT '' NOT NULL,
	clan_contact BLOB SUB_TYPE TEXT CHARACTER SET UTF8 DEFAULT '' NOT NULL,
	clan_logo BLOB SUB_TYPE TEXT CHARACTER SET UTF8 DEFAULT '' NOT NULL,
	clan_owner INTEGER DEFAULT 0 NOT NULL,
	clan_ownerb INTEGER DEFAULT 0 NOT NULL,
	bbcode_uid VARCHAR(8) CHARACTER SET NONE DEFAULT '' NOT NULL,
	bbcode_bitfield VARCHAR(255) CHARACTER SET NONE DEFAULT '' NOT NULL,
	bbcode_options INTEGER DEFAULT 0 NOT NULL
);;

ALTER TABLE phpbb_rivals_clans ADD PRIMARY KEY (clan_id);;


CREATE GENERATOR phpbb_rivals_clans_gen;;
SET GENERATOR phpbb_rivals_clans_gen TO 0;;

CREATE TRIGGER t_phpbb_rivals_clans FOR phpbb_rivals_clans
BEFORE INSERT
AS
BEGIN
	NEW.clan_id = GEN_ID(phpbb_rivals_clans_gen, 1);
END;;


# Table: 'phpbb_rivals_clansdata'
CREATE TABLE phpbb_rivals_clansdata (
	clan_id INTEGER DEFAULT 0 NOT NULL,
	clan_wins INTEGER DEFAULT 0 NOT NULL,
	clan_losses INTEGER DEFAULT 0 NOT NULL,
	clan_ties INTEGER DEFAULT 0 NOT NULL,
	clan_score INTEGER DEFAULT 0 NOT NULL,
	clan_lastscore INTEGER DEFAULT 0 NOT NULL,
	clan_streak INTEGER DEFAULT 0 NOT NULL,
	clan_ladder INTEGER DEFAULT 0 NOT NULL,
	clan_current_rank INTEGER DEFAULT 0 NOT NULL,
	clan_last_rank INTEGER DEFAULT 0 NOT NULL,
	clan_best_rank INTEGER DEFAULT 0 NOT NULL,
	clan_worst_rank INTEGER DEFAULT 0 NOT NULL
);;


# Table: 'phpbb_rivals_ladders'
CREATE TABLE phpbb_rivals_ladders (
	ladder_id INTEGER NOT NULL,
	ladder_name VARCHAR(255) CHARACTER SET NONE DEFAULT '' NOT NULL,
	ladder_desc BLOB SUB_TYPE TEXT CHARACTER SET UTF8 DEFAULT '' NOT NULL,
	ladder_rules BLOB SUB_TYPE TEXT CHARACTER SET UTF8 DEFAULT '' NOT NULL,
	ladder_order INTEGER DEFAULT 0 NOT NULL,
	ladder_rm INTEGER DEFAULT 0 NOT NULL,
	subladder_order INTEGER DEFAULT 0 NOT NULL,
	ladder_locked INTEGER DEFAULT 0 NOT NULL,
	ladder_cl INTEGER DEFAULT 1 NOT NULL,
	ladder_ranking INTEGER DEFAULT 0 NOT NULL,
	ladder_parent INTEGER DEFAULT 0 NOT NULL,
	ladder_platform INTEGER DEFAULT 0 NOT NULL,
	bbcode_uid VARCHAR(8) CHARACTER SET NONE DEFAULT '' NOT NULL,
	bbcode_bitfield VARCHAR(255) CHARACTER SET NONE DEFAULT '' NOT NULL,
	bbcode_options INTEGER DEFAULT 0 NOT NULL
);;

ALTER TABLE phpbb_rivals_ladders ADD PRIMARY KEY (ladder_id);;


CREATE GENERATOR phpbb_rivals_ladders_gen;;
SET GENERATOR phpbb_rivals_ladders_gen TO 0;;

CREATE TRIGGER t_phpbb_rivals_ladders FOR phpbb_rivals_ladders
BEFORE INSERT
AS
BEGIN
	NEW.ladder_id = GEN_ID(phpbb_rivals_ladders_gen, 1);
END;;


# Table: 'phpbb_rivals_seasons'
CREATE TABLE phpbb_rivals_seasons (
	season_id INTEGER NOT NULL,
	season_name VARCHAR(255) CHARACTER SET NONE DEFAULT '' NOT NULL,
	season_ladder INTEGER DEFAULT 0 NOT NULL,
	season_status INTEGER DEFAULT 1 NOT NULL
);;

ALTER TABLE phpbb_rivals_seasons ADD PRIMARY KEY (season_id);;


CREATE GENERATOR phpbb_rivals_seasons_gen;;
SET GENERATOR phpbb_rivals_seasons_gen TO 0;;

CREATE TRIGGER t_phpbb_rivals_seasons FOR phpbb_rivals_seasons
BEFORE INSERT
AS
BEGIN
	NEW.season_id = GEN_ID(phpbb_rivals_seasons_gen, 1);
END;;


# Table: 'phpbb_rivals_seasondata'
CREATE TABLE phpbb_rivals_seasondata (
	season_id INTEGER DEFAULT 0 NOT NULL,
	clan_id INTEGER DEFAULT 0 NOT NULL,
	clan_wins INTEGER DEFAULT 0 NOT NULL,
	clan_losses INTEGER DEFAULT 0 NOT NULL,
	clan_score INTEGER DEFAULT 0 NOT NULL,
	clan_streak INTEGER DEFAULT 0 NOT NULL,
	clan_current_rank INTEGER DEFAULT 0 NOT NULL,
	clan_last_rank INTEGER DEFAULT 0 NOT NULL,
	clan_ladder INTEGER DEFAULT 0 NOT NULL,
	clan_best_rank INTEGER DEFAULT 0 NOT NULL,
	clan_worst_rank INTEGER DEFAULT 0 NOT NULL
);;


# Table: 'phpbb_rivals_matchcomm'
CREATE TABLE phpbb_rivals_matchcomm (
	match_id INTEGER DEFAULT 0 NOT NULL,
	clan_id INTEGER DEFAULT 0 NOT NULL,
	matchcomm_message BLOB SUB_TYPE TEXT CHARACTER SET UTF8 DEFAULT '' NOT NULL,
	matchcomm_time INTEGER DEFAULT 0 NOT NULL,
	matchcomm_unread INTEGER DEFAULT 1 NOT NULL
);;


# Table: 'phpbb_rivals_matches'
CREATE TABLE phpbb_rivals_matches (
	match_id INTEGER NOT NULL,
	match_ladder INTEGER DEFAULT 0 NOT NULL,
	match_challenger INTEGER DEFAULT 0 NOT NULL,
	match_challengee INTEGER DEFAULT 0 NOT NULL,
	match_status INTEGER DEFAULT 0 NOT NULL,
	match_finishtime INTEGER DEFAULT 0 NOT NULL,
	match_posttime INTEGER DEFAULT 0 NOT NULL,
	match_details BLOB SUB_TYPE TEXT CHARACTER SET UTF8 DEFAULT '' NOT NULL,
	match_winner INTEGER DEFAULT 0 NOT NULL,
	match_looser INTEGER DEFAULT 0 NOT NULL,
	match_winnerscore INTEGER DEFAULT 0 NOT NULL,
	match_looserscore INTEGER DEFAULT 0 NOT NULL
);;

ALTER TABLE phpbb_rivals_matches ADD PRIMARY KEY (match_id);;


CREATE GENERATOR phpbb_rivals_matches_gen;;
SET GENERATOR phpbb_rivals_matches_gen TO 0;;

CREATE TRIGGER t_phpbb_rivals_matches FOR phpbb_rivals_matches
BEFORE INSERT
AS
BEGIN
	NEW.match_id = GEN_ID(phpbb_rivals_matches_gen, 1);
END;;


# Table: 'phpbb_rivals_matchfinder'
CREATE TABLE phpbb_rivals_matchfinder (
	match_id INTEGER NOT NULL,
	match_clanid INTEGER DEFAULT 0 NOT NULL,
	match_ladder INTEGER DEFAULT 0 NOT NULL,
	match_time INTEGER DEFAULT 0 NOT NULL,
	match_initaltime INTEGER DEFAULT 0 NOT NULL
);;

ALTER TABLE phpbb_rivals_matchfinder ADD PRIMARY KEY (match_id);;


CREATE GENERATOR phpbb_rivals_matchfinder_gen;;
SET GENERATOR phpbb_rivals_matchfinder_gen TO 0;;

CREATE TRIGGER t_phpbb_rivals_matchfinder FOR phpbb_rivals_matchfinder
BEFORE INSERT
AS
BEGIN
	NEW.match_id = GEN_ID(phpbb_rivals_matchfinder_gen, 1);
END;;


# Table: 'phpbb_rivals_platforms'
CREATE TABLE phpbb_rivals_platforms (
	platform_id INTEGER NOT NULL,
	platform_name VARCHAR(255) CHARACTER SET NONE DEFAULT '' NOT NULL
);;

ALTER TABLE phpbb_rivals_platforms ADD PRIMARY KEY (platform_id);;


CREATE GENERATOR phpbb_rivals_platforms_gen;;
SET GENERATOR phpbb_rivals_platforms_gen TO 0;;

CREATE TRIGGER t_phpbb_rivals_platforms FOR phpbb_rivals_platforms
BEFORE INSERT
AS
BEGIN
	NEW.platform_id = GEN_ID(phpbb_rivals_platforms_gen, 1);
END;;


# Table: 'phpbb_rivals_tclans'
CREATE TABLE phpbb_rivals_tclans (
	clan_tournament INTEGER DEFAULT 0 NOT NULL,
	clan_id INTEGER DEFAULT 0 NOT NULL,
	clan_bracket INTEGER DEFAULT 0 NOT NULL,
	clan_position INTEGER DEFAULT 0 NOT NULL,
	clan_looser INTEGER DEFAULT 0 NOT NULL
);;


# Table: 'phpbb_rivals_tournaments'
CREATE TABLE phpbb_rivals_tournaments (
	tournament_id INTEGER NOT NULL,
	tournament_name VARCHAR(255) CHARACTER SET NONE DEFAULT '' NOT NULL,
	tournament_brackets INTEGER DEFAULT 0 NOT NULL,
	tournament_status INTEGER DEFAULT 0 NOT NULL,
	tournament_type INTEGER DEFAULT 0 NOT NULL,
	tournament_season INTEGER DEFAULT 0 NOT NULL,
	tournament_finishedclans BLOB SUB_TYPE TEXT CHARACTER SET UTF8 DEFAULT '' NOT NULL,
	tournament_info BLOB SUB_TYPE TEXT CHARACTER SET UTF8 DEFAULT '' NOT NULL,
	tournament_direction INTEGER DEFAULT 0 NOT NULL,
	tournament_time INTEGER DEFAULT 0 NOT NULL,
	tournament_startdate INTEGER DEFAULT 0 NOT NULL,
	tournament_ladder INTEGER DEFAULT 0 NOT NULL,
	tournament_rm INTEGER DEFAULT 0 NOT NULL,
	bbcode_uid VARCHAR(8) CHARACTER SET NONE DEFAULT '' NOT NULL,
	bbcode_bitfield VARCHAR(255) CHARACTER SET NONE DEFAULT '' NOT NULL,
	bbcode_options INTEGER DEFAULT 0 NOT NULL
);;

ALTER TABLE phpbb_rivals_tournaments ADD PRIMARY KEY (tournament_id);;


CREATE GENERATOR phpbb_rivals_tournaments_gen;;
SET GENERATOR phpbb_rivals_tournaments_gen TO 0;;

CREATE TRIGGER t_phpbb_rivals_tournaments FOR phpbb_rivals_tournaments
BEFORE INSERT
AS
BEGIN
	NEW.tournament_id = GEN_ID(phpbb_rivals_tournaments_gen, 1);
END;;


# Table: 'phpbb_rivals_treports'
CREATE TABLE phpbb_rivals_treports (
	report_id INTEGER NOT NULL,
	report_tournament INTEGER DEFAULT 0 NOT NULL,
	clan_1 VARCHAR(255) CHARACTER SET NONE DEFAULT '' NOT NULL,
	clan_2 VARCHAR(255) CHARACTER SET NONE DEFAULT '' NOT NULL,
	clan_r1 BLOB SUB_TYPE TEXT CHARACTER SET UTF8 DEFAULT '' NOT NULL,
	clan_r2 BLOB SUB_TYPE TEXT CHARACTER SET UTF8 DEFAULT '' NOT NULL,
	report_time INTEGER DEFAULT 0 NOT NULL,
	clan_1id INTEGER DEFAULT 0 NOT NULL,
	clan_2id INTEGER DEFAULT 0 NOT NULL
);;

ALTER TABLE phpbb_rivals_treports ADD PRIMARY KEY (report_id);;


CREATE GENERATOR phpbb_rivals_treports_gen;;
SET GENERATOR phpbb_rivals_treports_gen TO 0;;

CREATE TRIGGER t_phpbb_rivals_treports FOR phpbb_rivals_treports
BEFORE INSERT
AS
BEGIN
	NEW.report_id = GEN_ID(phpbb_rivals_treports_gen, 1);
END;;


