/*

 $Id: $

*/

/*
  This first section is optional, however its probably the best method
  of running phpBB on Oracle. If you already have a tablespace and user created
  for phpBB you can leave this section commented out!

  The first set of statements create a phpBB tablespace and a phpBB user,
  make sure you change the password of the phpBB user before you run this script!!
*/

/*
CREATE TABLESPACE "PHPBB"
	LOGGING
	DATAFILE 'E:\ORACLE\ORADATA\LOCAL\PHPBB.ora'
	SIZE 10M
	AUTOEXTEND ON NEXT 10M
	MAXSIZE 100M;

CREATE USER "PHPBB"
	PROFILE "DEFAULT"
	IDENTIFIED BY "phpbb_password"
	DEFAULT TABLESPACE "PHPBB"
	QUOTA UNLIMITED ON "PHPBB"
	ACCOUNT UNLOCK;

GRANT ANALYZE ANY TO "PHPBB";
GRANT CREATE SEQUENCE TO "PHPBB";
GRANT CREATE SESSION TO "PHPBB";
GRANT CREATE TABLE TO "PHPBB";
GRANT CREATE TRIGGER TO "PHPBB";
GRANT CREATE VIEW TO "PHPBB";
GRANT "CONNECT" TO "PHPBB";

COMMIT;
DISCONNECT;

CONNECT phpbb/phpbb_password;
*/
/*
	Table: 'phpbb_rivals_challenges'
*/
CREATE TABLE phpbb_rivals_challenges (
	challenge_id number(8) NOT NULL,
	challenge_ladder number(8) DEFAULT '0' NOT NULL,
	challenger number(8) DEFAULT '0' NOT NULL,
	challengee number(8) DEFAULT '0' NOT NULL,
	challenge_posttime number(11) DEFAULT '0' NOT NULL,
	challenge_details clob DEFAULT '' ,
	CONSTRAINT pk_phpbb_rivals_challenges PRIMARY KEY (challenge_id)
)
/


CREATE SEQUENCE phpbb_rivals_challenges_seq
/

CREATE OR REPLACE TRIGGER t_phpbb_rivals_challenges
BEFORE INSERT ON phpbb_rivals_challenges
FOR EACH ROW WHEN (
	new.challenge_id IS NULL OR new.challenge_id = 0
)
BEGIN
	SELECT phpbb_rivals_challenges_seq.nextval
	INTO :new.challenge_id
	FROM dual;
END;
/


/*
	Table: 'phpbb_rivals_clanmembers'
*/
CREATE TABLE phpbb_rivals_clanmembers (
	member_id number(8) NOT NULL,
	member_clan number(8) DEFAULT '0' NOT NULL,
	member_userid number(8) DEFAULT '0' NOT NULL,
	member_status number(4) DEFAULT '0' NOT NULL,
	CONSTRAINT pk_phpbb_rivals_clanmembers PRIMARY KEY (member_id)
)
/


CREATE SEQUENCE phpbb_rivals_clanmembers_seq
/

CREATE OR REPLACE TRIGGER t_phpbb_rivals_clanmembers
BEFORE INSERT ON phpbb_rivals_clanmembers
FOR EACH ROW WHEN (
	new.member_id IS NULL OR new.member_id = 0
)
BEGIN
	SELECT phpbb_rivals_clanmembers_seq.nextval
	INTO :new.member_id
	FROM dual;
END;
/


/*
	Table: 'phpbb_rivals_clans'
*/
CREATE TABLE phpbb_rivals_clans (
	clan_id number(8) NOT NULL,
	clan_name varchar2(255) DEFAULT '' ,
	clan_tag varchar2(255) DEFAULT '' ,
	clan_tournaments clob DEFAULT '' ,
	clan_contact clob DEFAULT '' ,
	clan_logo clob DEFAULT '' ,
	clan_owner number(8) DEFAULT '0' NOT NULL,
	clan_ownerb number(8) DEFAULT '0' NOT NULL,
	bbcode_uid varchar2(8) DEFAULT '' ,
	bbcode_bitfield varchar2(255) DEFAULT '' ,
	bbcode_options number(4) DEFAULT '0' NOT NULL,
	CONSTRAINT pk_phpbb_rivals_clans PRIMARY KEY (clan_id)
)
/


CREATE SEQUENCE phpbb_rivals_clans_seq
/

CREATE OR REPLACE TRIGGER t_phpbb_rivals_clans
BEFORE INSERT ON phpbb_rivals_clans
FOR EACH ROW WHEN (
	new.clan_id IS NULL OR new.clan_id = 0
)
BEGIN
	SELECT phpbb_rivals_clans_seq.nextval
	INTO :new.clan_id
	FROM dual;
END;
/


/*
	Table: 'phpbb_rivals_clansdata'
*/
CREATE TABLE phpbb_rivals_clansdata (
	clan_id number(8) DEFAULT '0' NOT NULL,
	clan_wins number(8) DEFAULT '0' NOT NULL,
	clan_losses number(8) DEFAULT '0' NOT NULL,
	clan_ties number(8) DEFAULT '0' NOT NULL,
	clan_score number(8) DEFAULT '0' NOT NULL,
	clan_lastscore number(8) DEFAULT '0' NOT NULL,
	clan_streak number(8) DEFAULT '0' NOT NULL,
	clan_ladder number(8) DEFAULT '0' NOT NULL,
	clan_current_rank number(8) DEFAULT '0' NOT NULL,
	clan_last_rank number(8) DEFAULT '0' NOT NULL,
	clan_best_rank number(8) DEFAULT '0' NOT NULL,
	clan_worst_rank number(8) DEFAULT '0' NOT NULL
)
/


/*
	Table: 'phpbb_rivals_ladders'
*/
CREATE TABLE phpbb_rivals_ladders (
	ladder_id number(8) NOT NULL,
	ladder_name varchar2(255) DEFAULT '' ,
	ladder_desc clob DEFAULT '' ,
	ladder_rules clob DEFAULT '' ,
	ladder_order number(8) DEFAULT '0' NOT NULL,
	ladder_rm number(8) DEFAULT '0' NOT NULL,
	subladder_order number(8) DEFAULT '0' NOT NULL,
	ladder_locked number(2) DEFAULT '0' NOT NULL,
	ladder_cl number(2) DEFAULT '1' NOT NULL,
	ladder_ranking number(2) DEFAULT '0' NOT NULL,
	ladder_parent number(8) DEFAULT '0' NOT NULL,
	ladder_platform number(8) DEFAULT '0' NOT NULL,
	bbcode_uid varchar2(8) DEFAULT '' ,
	bbcode_bitfield varchar2(255) DEFAULT '' ,
	bbcode_options number(4) DEFAULT '0' NOT NULL,
	CONSTRAINT pk_phpbb_rivals_ladders PRIMARY KEY (ladder_id)
)
/


CREATE SEQUENCE phpbb_rivals_ladders_seq
/

CREATE OR REPLACE TRIGGER t_phpbb_rivals_ladders
BEFORE INSERT ON phpbb_rivals_ladders
FOR EACH ROW WHEN (
	new.ladder_id IS NULL OR new.ladder_id = 0
)
BEGIN
	SELECT phpbb_rivals_ladders_seq.nextval
	INTO :new.ladder_id
	FROM dual;
END;
/


/*
	Table: 'phpbb_rivals_seasons'
*/
CREATE TABLE phpbb_rivals_seasons (
	season_id number(8) NOT NULL,
	season_name varchar2(255) DEFAULT '' ,
	season_ladder number(8) DEFAULT '0' NOT NULL,
	season_status number(2) DEFAULT '1' NOT NULL,
	CONSTRAINT pk_phpbb_rivals_seasons PRIMARY KEY (season_id)
)
/


CREATE SEQUENCE phpbb_rivals_seasons_seq
/

CREATE OR REPLACE TRIGGER t_phpbb_rivals_seasons
BEFORE INSERT ON phpbb_rivals_seasons
FOR EACH ROW WHEN (
	new.season_id IS NULL OR new.season_id = 0
)
BEGIN
	SELECT phpbb_rivals_seasons_seq.nextval
	INTO :new.season_id
	FROM dual;
END;
/


/*
	Table: 'phpbb_rivals_seasondata'
*/
CREATE TABLE phpbb_rivals_seasondata (
	season_id number(8) DEFAULT '0' NOT NULL,
	clan_id number(8) DEFAULT '0' NOT NULL,
	clan_wins number(8) DEFAULT '0' NOT NULL,
	clan_losses number(8) DEFAULT '0' NOT NULL,
	clan_score number(8) DEFAULT '0' NOT NULL,
	clan_streak number(8) DEFAULT '0' NOT NULL,
	clan_current_rank number(8) DEFAULT '0' NOT NULL,
	clan_last_rank number(8) DEFAULT '0' NOT NULL,
	clan_ladder number(8) DEFAULT '0' NOT NULL,
	clan_best_rank number(8) DEFAULT '0' NOT NULL,
	clan_worst_rank number(8) DEFAULT '0' NOT NULL
)
/


/*
	Table: 'phpbb_rivals_matchcomm'
*/
CREATE TABLE phpbb_rivals_matchcomm (
	match_id number(8) DEFAULT '0' NOT NULL,
	clan_id number(8) DEFAULT '0' NOT NULL,
	matchcomm_message clob DEFAULT '' ,
	matchcomm_time number(11) DEFAULT '0' NOT NULL,
	matchcomm_unread number(2) DEFAULT '1' NOT NULL
)
/


/*
	Table: 'phpbb_rivals_matches'
*/
CREATE TABLE phpbb_rivals_matches (
	match_id number(8) NOT NULL,
	match_ladder number(8) DEFAULT '0' NOT NULL,
	match_challenger number(8) DEFAULT '0' NOT NULL,
	match_challengee number(8) DEFAULT '0' NOT NULL,
	match_status number(4) DEFAULT '0' NOT NULL,
	match_finishtime number(11) DEFAULT '0' NOT NULL,
	match_posttime number(11) DEFAULT '0' NOT NULL,
	match_details clob DEFAULT '' ,
	match_winner number(8) DEFAULT '0' NOT NULL,
	match_looser number(8) DEFAULT '0' NOT NULL,
	match_winnerscore number(8) DEFAULT '0' NOT NULL,
	match_looserscore number(8) DEFAULT '0' NOT NULL,
	CONSTRAINT pk_phpbb_rivals_matches PRIMARY KEY (match_id)
)
/


CREATE SEQUENCE phpbb_rivals_matches_seq
/

CREATE OR REPLACE TRIGGER t_phpbb_rivals_matches
BEFORE INSERT ON phpbb_rivals_matches
FOR EACH ROW WHEN (
	new.match_id IS NULL OR new.match_id = 0
)
BEGIN
	SELECT phpbb_rivals_matches_seq.nextval
	INTO :new.match_id
	FROM dual;
END;
/


/*
	Table: 'phpbb_rivals_matchfinder'
*/
CREATE TABLE phpbb_rivals_matchfinder (
	match_id number(8) NOT NULL,
	match_clanid number(8) DEFAULT '0' NOT NULL,
	match_ladder number(8) DEFAULT '0' NOT NULL,
	match_time number(11) DEFAULT '0' NOT NULL,
	match_initaltime number(11) DEFAULT '0' NOT NULL,
	CONSTRAINT pk_phpbb_rivals_matchfinder PRIMARY KEY (match_id)
)
/


CREATE SEQUENCE phpbb_rivals_matchfinder_seq
/

CREATE OR REPLACE TRIGGER t_phpbb_rivals_matchfinder
BEFORE INSERT ON phpbb_rivals_matchfinder
FOR EACH ROW WHEN (
	new.match_id IS NULL OR new.match_id = 0
)
BEGIN
	SELECT phpbb_rivals_matchfinder_seq.nextval
	INTO :new.match_id
	FROM dual;
END;
/


/*
	Table: 'phpbb_rivals_platforms'
*/
CREATE TABLE phpbb_rivals_platforms (
	platform_id number(8) NOT NULL,
	platform_name varchar2(255) DEFAULT '' ,
	CONSTRAINT pk_phpbb_rivals_platforms PRIMARY KEY (platform_id)
)
/


CREATE SEQUENCE phpbb_rivals_platforms_seq
/

CREATE OR REPLACE TRIGGER t_phpbb_rivals_platforms
BEFORE INSERT ON phpbb_rivals_platforms
FOR EACH ROW WHEN (
	new.platform_id IS NULL OR new.platform_id = 0
)
BEGIN
	SELECT phpbb_rivals_platforms_seq.nextval
	INTO :new.platform_id
	FROM dual;
END;
/


/*
	Table: 'phpbb_rivals_tclans'
*/
CREATE TABLE phpbb_rivals_tclans (
	clan_tournament number(8) DEFAULT '0' NOT NULL,
	clan_id number(8) DEFAULT '0' NOT NULL,
	clan_bracket number(8) DEFAULT '0' NOT NULL,
	clan_position number(8) DEFAULT '0' NOT NULL,
	clan_looser number(2) DEFAULT '0' NOT NULL
)
/


/*
	Table: 'phpbb_rivals_tournaments'
*/
CREATE TABLE phpbb_rivals_tournaments (
	tournament_id number(8) NOT NULL,
	tournament_name varchar2(255) DEFAULT '' ,
	tournament_brackets number(8) DEFAULT '0' NOT NULL,
	tournament_status number(4) DEFAULT '0' NOT NULL,
	tournament_type number(8) DEFAULT '0' NOT NULL,
	tournament_season number(8) DEFAULT '0' NOT NULL,
	tournament_finishedclans clob DEFAULT '' ,
	tournament_info clob DEFAULT '' ,
	tournament_direction number(2) DEFAULT '0' NOT NULL,
	tournament_time number(11) DEFAULT '0' NOT NULL,
	tournament_startdate number(11) DEFAULT '0' NOT NULL,
	tournament_ladder number(8) DEFAULT '0' NOT NULL,
	tournament_rm number(8) DEFAULT '0' NOT NULL,
	bbcode_uid varchar2(8) DEFAULT '' ,
	bbcode_bitfield varchar2(255) DEFAULT '' ,
	bbcode_options number(4) DEFAULT '0' NOT NULL,
	CONSTRAINT pk_phpbb_rivals_tournaments PRIMARY KEY (tournament_id)
)
/


CREATE SEQUENCE phpbb_rivals_tournaments_seq
/

CREATE OR REPLACE TRIGGER t_phpbb_rivals_tournaments
BEFORE INSERT ON phpbb_rivals_tournaments
FOR EACH ROW WHEN (
	new.tournament_id IS NULL OR new.tournament_id = 0
)
BEGIN
	SELECT phpbb_rivals_tournaments_seq.nextval
	INTO :new.tournament_id
	FROM dual;
END;
/


/*
	Table: 'phpbb_rivals_treports'
*/
CREATE TABLE phpbb_rivals_treports (
	report_id number(8) NOT NULL,
	report_tournament number(8) DEFAULT '0' NOT NULL,
	clan_1 varchar2(255) DEFAULT '' ,
	clan_2 varchar2(255) DEFAULT '' ,
	clan_r1 clob DEFAULT '' ,
	clan_r2 clob DEFAULT '' ,
	report_time number(11) DEFAULT '0' NOT NULL,
	clan_1id number(8) DEFAULT '0' NOT NULL,
	clan_2id number(8) DEFAULT '0' NOT NULL,
	CONSTRAINT pk_phpbb_rivals_treports PRIMARY KEY (report_id)
)
/


CREATE SEQUENCE phpbb_rivals_treports_seq
/

CREATE OR REPLACE TRIGGER t_phpbb_rivals_treports
BEFORE INSERT ON phpbb_rivals_treports
FOR EACH ROW WHEN (
	new.report_id IS NULL OR new.report_id = 0
)
BEGIN
	SELECT phpbb_rivals_treports_seq.nextval
	INTO :new.report_id
	FROM dual;
END;
/


