/*

 $Id: $

*/

BEGIN;

/*
	Domain definition
*/
CREATE DOMAIN varchar_ci AS varchar(255) NOT NULL DEFAULT ''::character varying;

/*
	Operation Functions
*/
CREATE FUNCTION _varchar_ci_equal(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) = LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_not_equal(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) != LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_less_than(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) < LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_less_equal(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) <= LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_greater_than(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) > LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_greater_equals(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) >= LOWER($2)' LANGUAGE SQL STRICT;

/*
	Operators
*/
CREATE OPERATOR <(
  PROCEDURE = _varchar_ci_less_than,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = >,
  NEGATOR = >=,
  RESTRICT = scalarltsel,
  JOIN = scalarltjoinsel);

CREATE OPERATOR <=(
  PROCEDURE = _varchar_ci_less_equal,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = >=,
  NEGATOR = >,
  RESTRICT = scalarltsel,
  JOIN = scalarltjoinsel);

CREATE OPERATOR >(
  PROCEDURE = _varchar_ci_greater_than,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = <,
  NEGATOR = <=,
  RESTRICT = scalargtsel,
  JOIN = scalargtjoinsel);

CREATE OPERATOR >=(
  PROCEDURE = _varchar_ci_greater_equals,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = <=,
  NEGATOR = <,
  RESTRICT = scalargtsel,
  JOIN = scalargtjoinsel);

CREATE OPERATOR <>(
  PROCEDURE = _varchar_ci_not_equal,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = <>,
  NEGATOR = =,
  RESTRICT = neqsel,
  JOIN = neqjoinsel);

CREATE OPERATOR =(
  PROCEDURE = _varchar_ci_equal,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = =,
  NEGATOR = <>,
  RESTRICT = eqsel,
  JOIN = eqjoinsel,
  HASHES,
  MERGES,
  SORT1= <);

/*
	Table: 'phpbb_rivals_challenges'
*/
CREATE SEQUENCE phpbb_rivals_challenges_seq;

CREATE TABLE phpbb_rivals_challenges (
	challenge_id INT4 DEFAULT nextval('phpbb_rivals_challenges_seq'),
	challenge_ladder INT4 DEFAULT '0' NOT NULL CHECK (challenge_ladder >= 0),
	challenger INT4 DEFAULT '0' NOT NULL CHECK (challenger >= 0),
	challengee INT4 DEFAULT '0' NOT NULL CHECK (challengee >= 0),
	challenge_posttime INT4 DEFAULT '0' NOT NULL,
	challenge_details varchar(4000) DEFAULT '' NOT NULL,
	PRIMARY KEY (challenge_id)
);


/*
	Table: 'phpbb_rivals_clanmembers'
*/
CREATE SEQUENCE phpbb_rivals_clanmembers_seq;

CREATE TABLE phpbb_rivals_clanmembers (
	member_id INT4 DEFAULT nextval('phpbb_rivals_clanmembers_seq'),
	member_clan INT4 DEFAULT '0' NOT NULL CHECK (member_clan >= 0),
	member_userid INT4 DEFAULT '0' NOT NULL CHECK (member_userid >= 0),
	member_status INT2 DEFAULT '0' NOT NULL CHECK (member_status >= 0),
	PRIMARY KEY (member_id)
);


/*
	Table: 'phpbb_rivals_clans'
*/
CREATE SEQUENCE phpbb_rivals_clans_seq;

CREATE TABLE phpbb_rivals_clans (
	clan_id INT4 DEFAULT nextval('phpbb_rivals_clans_seq'),
	clan_name varchar(255) DEFAULT '' NOT NULL,
	clan_tag varchar(255) DEFAULT '' NOT NULL,
	clan_tournaments varchar(4000) DEFAULT '' NOT NULL,
	clan_contact varchar(4000) DEFAULT '' NOT NULL,
	clan_logo varchar(4000) DEFAULT '' NOT NULL,
	clan_owner INT4 DEFAULT '0' NOT NULL CHECK (clan_owner >= 0),
	clan_ownerb INT4 DEFAULT '0' NOT NULL CHECK (clan_ownerb >= 0),
	bbcode_uid varchar(8) DEFAULT '' NOT NULL,
	bbcode_bitfield varchar(255) DEFAULT '' NOT NULL,
	bbcode_options INT4 DEFAULT '0' NOT NULL CHECK (bbcode_options >= 0),
	PRIMARY KEY (clan_id)
);


/*
	Table: 'phpbb_rivals_clansdata'
*/
CREATE TABLE phpbb_rivals_clansdata (
	clan_id INT4 DEFAULT '0' NOT NULL CHECK (clan_id >= 0),
	clan_wins INT4 DEFAULT '0' NOT NULL CHECK (clan_wins >= 0),
	clan_losses INT4 DEFAULT '0' NOT NULL CHECK (clan_losses >= 0),
	clan_ties INT4 DEFAULT '0' NOT NULL CHECK (clan_ties >= 0),
	clan_score INT4 DEFAULT '0' NOT NULL CHECK (clan_score >= 0),
	clan_lastscore INT4 DEFAULT '0' NOT NULL CHECK (clan_lastscore >= 0),
	clan_streak INT4 DEFAULT '0' NOT NULL CHECK (clan_streak >= 0),
	clan_ladder INT4 DEFAULT '0' NOT NULL CHECK (clan_ladder >= 0),
	clan_current_rank INT4 DEFAULT '0' NOT NULL CHECK (clan_current_rank >= 0),
	clan_last_rank INT4 DEFAULT '0' NOT NULL CHECK (clan_last_rank >= 0),
	clan_best_rank INT4 DEFAULT '0' NOT NULL CHECK (clan_best_rank >= 0),
	clan_worst_rank INT4 DEFAULT '0' NOT NULL CHECK (clan_worst_rank >= 0)
);


/*
	Table: 'phpbb_rivals_ladders'
*/
CREATE SEQUENCE phpbb_rivals_ladders_seq;

CREATE TABLE phpbb_rivals_ladders (
	ladder_id INT4 DEFAULT nextval('phpbb_rivals_ladders_seq'),
	ladder_name varchar(255) DEFAULT '' NOT NULL,
	ladder_desc varchar(4000) DEFAULT '' NOT NULL,
	ladder_rules varchar(4000) DEFAULT '' NOT NULL,
	ladder_order INT4 DEFAULT '0' NOT NULL CHECK (ladder_order >= 0),
	ladder_rm INT4 DEFAULT '0' NOT NULL CHECK (ladder_rm >= 0),
	subladder_order INT4 DEFAULT '0' NOT NULL CHECK (subladder_order >= 0),
	ladder_locked INT2 DEFAULT '0' NOT NULL,
	ladder_cl INT2 DEFAULT '1' NOT NULL,
	ladder_ranking INT2 DEFAULT '0' NOT NULL,
	ladder_parent INT4 DEFAULT '0' NOT NULL CHECK (ladder_parent >= 0),
	ladder_platform INT4 DEFAULT '0' NOT NULL CHECK (ladder_platform >= 0),
	bbcode_uid varchar(8) DEFAULT '' NOT NULL,
	bbcode_bitfield varchar(255) DEFAULT '' NOT NULL,
	bbcode_options INT4 DEFAULT '0' NOT NULL CHECK (bbcode_options >= 0),
	PRIMARY KEY (ladder_id)
);


/*
	Table: 'phpbb_rivals_seasons'
*/
CREATE SEQUENCE phpbb_rivals_seasons_seq;

CREATE TABLE phpbb_rivals_seasons (
	season_id INT4 DEFAULT nextval('phpbb_rivals_seasons_seq'),
	season_name varchar(255) DEFAULT '' NOT NULL,
	season_ladder INT4 DEFAULT '0' NOT NULL CHECK (season_ladder >= 0),
	season_status INT2 DEFAULT '1' NOT NULL,
	PRIMARY KEY (season_id)
);


/*
	Table: 'phpbb_rivals_seasondata'
*/
CREATE TABLE phpbb_rivals_seasondata (
	season_id INT4 DEFAULT '0' NOT NULL CHECK (season_id >= 0),
	clan_id INT4 DEFAULT '0' NOT NULL CHECK (clan_id >= 0),
	clan_wins INT4 DEFAULT '0' NOT NULL CHECK (clan_wins >= 0),
	clan_losses INT4 DEFAULT '0' NOT NULL CHECK (clan_losses >= 0),
	clan_score INT4 DEFAULT '0' NOT NULL CHECK (clan_score >= 0),
	clan_streak INT4 DEFAULT '0' NOT NULL,
	clan_current_rank INT4 DEFAULT '0' NOT NULL CHECK (clan_current_rank >= 0),
	clan_last_rank INT4 DEFAULT '0' NOT NULL CHECK (clan_last_rank >= 0),
	clan_ladder INT4 DEFAULT '0' NOT NULL CHECK (clan_ladder >= 0),
	clan_best_rank INT4 DEFAULT '0' NOT NULL CHECK (clan_best_rank >= 0),
	clan_worst_rank INT4 DEFAULT '0' NOT NULL CHECK (clan_worst_rank >= 0)
);


/*
	Table: 'phpbb_rivals_matchcomm'
*/
CREATE TABLE phpbb_rivals_matchcomm (
	match_id INT4 DEFAULT '0' NOT NULL CHECK (match_id >= 0),
	clan_id INT4 DEFAULT '0' NOT NULL CHECK (clan_id >= 0),
	matchcomm_message varchar(4000) DEFAULT '' NOT NULL,
	matchcomm_time INT4 DEFAULT '0' NOT NULL,
	matchcomm_unread INT2 DEFAULT '1' NOT NULL
);


/*
	Table: 'phpbb_rivals_matches'
*/
CREATE SEQUENCE phpbb_rivals_matches_seq;

CREATE TABLE phpbb_rivals_matches (
	match_id INT4 DEFAULT nextval('phpbb_rivals_matches_seq'),
	match_ladder INT4 DEFAULT '0' NOT NULL CHECK (match_ladder >= 0),
	match_challenger INT4 DEFAULT '0' NOT NULL CHECK (match_challenger >= 0),
	match_challengee INT4 DEFAULT '0' NOT NULL CHECK (match_challengee >= 0),
	match_status INT2 DEFAULT '0' NOT NULL CHECK (match_status >= 0),
	match_finishtime INT4 DEFAULT '0' NOT NULL,
	match_posttime INT4 DEFAULT '0' NOT NULL,
	match_details varchar(4000) DEFAULT '' NOT NULL,
	match_winner INT4 DEFAULT '0' NOT NULL CHECK (match_winner >= 0),
	match_looser INT4 DEFAULT '0' NOT NULL CHECK (match_looser >= 0),
	match_winnerscore INT4 DEFAULT '0' NOT NULL CHECK (match_winnerscore >= 0),
	match_looserscore INT4 DEFAULT '0' NOT NULL CHECK (match_looserscore >= 0),
	PRIMARY KEY (match_id)
);


/*
	Table: 'phpbb_rivals_matchfinder'
*/
CREATE SEQUENCE phpbb_rivals_matchfinder_seq;

CREATE TABLE phpbb_rivals_matchfinder (
	match_id INT4 DEFAULT nextval('phpbb_rivals_matchfinder_seq'),
	match_clanid INT4 DEFAULT '0' NOT NULL CHECK (match_clanid >= 0),
	match_ladder INT4 DEFAULT '0' NOT NULL CHECK (match_ladder >= 0),
	match_time INT4 DEFAULT '0' NOT NULL,
	match_initaltime INT4 DEFAULT '0' NOT NULL,
	PRIMARY KEY (match_id)
);


/*
	Table: 'phpbb_rivals_platforms'
*/
CREATE SEQUENCE phpbb_rivals_platforms_seq;

CREATE TABLE phpbb_rivals_platforms (
	platform_id INT4 DEFAULT nextval('phpbb_rivals_platforms_seq'),
	platform_name varchar(255) DEFAULT '' NOT NULL,
	PRIMARY KEY (platform_id)
);


/*
	Table: 'phpbb_rivals_tclans'
*/
CREATE TABLE phpbb_rivals_tclans (
	clan_tournament INT4 DEFAULT '0' NOT NULL CHECK (clan_tournament >= 0),
	clan_id INT4 DEFAULT '0' NOT NULL CHECK (clan_id >= 0),
	clan_bracket INT4 DEFAULT '0' NOT NULL CHECK (clan_bracket >= 0),
	clan_position INT4 DEFAULT '0' NOT NULL CHECK (clan_position >= 0),
	clan_looser INT2 DEFAULT '0' NOT NULL
);


/*
	Table: 'phpbb_rivals_tournaments'
*/
CREATE SEQUENCE phpbb_rivals_tournaments_seq;

CREATE TABLE phpbb_rivals_tournaments (
	tournament_id INT4 DEFAULT nextval('phpbb_rivals_tournaments_seq'),
	tournament_name varchar(255) DEFAULT '' NOT NULL,
	tournament_brackets INT4 DEFAULT '0' NOT NULL CHECK (tournament_brackets >= 0),
	tournament_status INT2 DEFAULT '0' NOT NULL CHECK (tournament_status >= 0),
	tournament_type INT4 DEFAULT '0' NOT NULL CHECK (tournament_type >= 0),
	tournament_season INT4 DEFAULT '0' NOT NULL CHECK (tournament_season >= 0),
	tournament_finishedclans varchar(4000) DEFAULT '' NOT NULL,
	tournament_info varchar(4000) DEFAULT '' NOT NULL,
	tournament_direction INT2 DEFAULT '0' NOT NULL,
	tournament_time INT4 DEFAULT '0' NOT NULL,
	tournament_startdate INT4 DEFAULT '0' NOT NULL,
	tournament_ladder INT4 DEFAULT '0' NOT NULL CHECK (tournament_ladder >= 0),
	tournament_rm INT4 DEFAULT '0' NOT NULL CHECK (tournament_rm >= 0),
	bbcode_uid varchar(8) DEFAULT '' NOT NULL,
	bbcode_bitfield varchar(255) DEFAULT '' NOT NULL,
	bbcode_options INT4 DEFAULT '0' NOT NULL CHECK (bbcode_options >= 0),
	PRIMARY KEY (tournament_id)
);


/*
	Table: 'phpbb_rivals_treports'
*/
CREATE SEQUENCE phpbb_rivals_treports_seq;

CREATE TABLE phpbb_rivals_treports (
	report_id INT4 DEFAULT nextval('phpbb_rivals_treports_seq'),
	report_tournament INT4 DEFAULT '0' NOT NULL CHECK (report_tournament >= 0),
	clan_1 varchar(255) DEFAULT '' NOT NULL,
	clan_2 varchar(255) DEFAULT '' NOT NULL,
	clan_r1 varchar(4000) DEFAULT '' NOT NULL,
	clan_r2 varchar(4000) DEFAULT '' NOT NULL,
	report_time INT4 DEFAULT '0' NOT NULL,
	clan_1id INT4 DEFAULT '0' NOT NULL CHECK (clan_1id >= 0),
	clan_2id INT4 DEFAULT '0' NOT NULL CHECK (clan_2id >= 0),
	PRIMARY KEY (report_id)
);



COMMIT;