/*

 $Id: $

*/

BEGIN;

/*
	Domain definition
*/
CREATE DOMAIN varchar_ci AS varchar(255) NOT NULL DEFAULT ''::character varying;

/*
	Operation Functions
*/
CREATE FUNCTION _varchar_ci_equal(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) = LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_not_equal(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) != LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_less_than(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) < LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_less_equal(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) <= LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_greater_than(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) > LOWER($2)' LANGUAGE SQL STRICT;
CREATE FUNCTION _varchar_ci_greater_equals(varchar_ci, varchar_ci) RETURNS boolean AS 'SELECT LOWER($1) >= LOWER($2)' LANGUAGE SQL STRICT;

/*
	Operators
*/
CREATE OPERATOR <(
  PROCEDURE = _varchar_ci_less_than,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = >,
  NEGATOR = >=,
  RESTRICT = scalarltsel,
  JOIN = scalarltjoinsel);

CREATE OPERATOR <=(
  PROCEDURE = _varchar_ci_less_equal,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = >=,
  NEGATOR = >,
  RESTRICT = scalarltsel,
  JOIN = scalarltjoinsel);

CREATE OPERATOR >(
  PROCEDURE = _varchar_ci_greater_than,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = <,
  NEGATOR = <=,
  RESTRICT = scalargtsel,
  JOIN = scalargtjoinsel);

CREATE OPERATOR >=(
  PROCEDURE = _varchar_ci_greater_equals,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = <=,
  NEGATOR = <,
  RESTRICT = scalargtsel,
  JOIN = scalargtjoinsel);

CREATE OPERATOR <>(
  PROCEDURE = _varchar_ci_not_equal,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = <>,
  NEGATOR = =,
  RESTRICT = neqsel,
  JOIN = neqjoinsel);

CREATE OPERATOR =(
  PROCEDURE = _varchar_ci_equal,
  LEFTARG = varchar_ci,
  RIGHTARG = varchar_ci,
  COMMUTATOR = =,
  NEGATOR = <>,
  RESTRICT = eqsel,
  JOIN = eqjoinsel,
  HASHES,
  MERGES,
  SORT1= <);

/*
	Table: 'phpbb_rivals_seasons'
*/
CREATE SEQUENCE phpbb_rivals_seasons_seq;

CREATE TABLE phpbb_rivals_seasons (
	season_id INT4 DEFAULT nextval('phpbb_rivals_seasons_seq'),
	season_name varchar(255) DEFAULT '' NOT NULL,
	season_ladder INT4 DEFAULT '0' NOT NULL CHECK (season_ladder >= 0),
	season_status INT2 DEFAULT '1' NOT NULL,
	PRIMARY KEY (season_id)
);


/*
	Table: 'phpbb_rivals_seasondata'
*/
CREATE TABLE phpbb_rivals_seasondata (
	season_id INT4 DEFAULT '0' NOT NULL CHECK (season_id >= 0),
	clan_id INT4 DEFAULT '0' NOT NULL CHECK (clan_id >= 0),
	clan_wins INT4 DEFAULT '0' NOT NULL CHECK (clan_wins >= 0),
	clan_losses INT4 DEFAULT '0' NOT NULL CHECK (clan_losses >= 0),
	clan_ties INT4 DEFAULT '0' NOT NULL CHECK (clan_ties >= 0),
	clan_score INT4 DEFAULT '0' NOT NULL CHECK (clan_score >= 0),
	clan_streak INT4 DEFAULT '0' NOT NULL CHECK (clan_streak >= 0),
	clan_current_rank INT4 DEFAULT '0' NOT NULL CHECK (clan_current_rank >= 0),
	clan_last_rank INT4 DEFAULT '0' NOT NULL CHECK (clan_last_rank >= 0),
	clan_ladder INT4 DEFAULT '0' NOT NULL CHECK (clan_ladder >= 0),
	clan_best_rank INT4 DEFAULT '0' NOT NULL CHECK (clan_best_rank >= 0),
	clan_worst_rank INT4 DEFAULT '0' NOT NULL CHECK (clan_worst_rank >= 0)
);



COMMIT;